@@ -1,15 +1,7 @@
-# -*- coding: utf-8 -*-
-"""
----------------------------------------------
-Copyright (c) 2025 ZhangYundi
-Licensed under the MIT License. 
-Created on 2025/7/4 10:38
-Email: yundi.xxii@outlook.com
-Description: 
----------------------------------------------
-"""
+# Copyright (c) ZhangYundi.
+# Licensed under the MIT License.
 
-__version__ = "1.1.17"
+__version__ = "2.0.5"
 
 from typing import Iterable
 
@@ -61,8 +53,10 @@ def update(tasks: tuple[str] = ("jydata", "mc")):
 
     update_settings = lidb.get_settings().get("UPDATES")
     if not update_settings:
-        logger.warning(f"Missing provider update configuration.")
-        return
+        logger.warning(f"Missing provider update configuration. Initialize jydata/mc configs from quda.data.init.")
+        import quda.data
+        quda.data.init()
+        update_settings = lidb.get_settings().get("UPDATES")
     for task, task_conf in update_settings.items():
         if task not in tasks:
             continue
