@@ -50,6 +50,8 @@ class Evaluator:
         query_cond = "" if not conds else f"where {' and '.join(conds)}"
         query = f"select * from {fac.tb_name} {query_cond};"
         data = lidb.sql(query).drop(FIELD_VERSION).cast({FIELD_DATE: pl.Utf8})
+        if eager:
+            return data.collect()
         return data
 
     @staticmethod
@@ -213,7 +215,7 @@ class Evaluator:
         if data is not None and ctx.codes is not None:
             target_index = pl.DataFrame({FIELD_ASSET: ctx.codes})
             data = target_index.join(data, on=FIELD_ASSET, how="left")
-        data = data.with_columns(pl.lit(ctx.time).alias(FIELD_TIME))
+        data = data.with_columns(pl.lit(ctx.time).alias(FIELD_TIME)).filter(pl.col(FIELD_DATE) >= ctx.beg_date, pl.col(FIELD_DATE) <= ctx.end_date)
         return data[cols].sort(INDEX)
 
     @staticmethod
